@@ -2,7 +2,9 @@ from marshmallow import (
     Schema,
     fields,
     validate,
+    pre_load
 )
+from ...utils.utils import pre_load_date_fields
 
 
 class PubmedResourceSchema(Schema):
@@ -11,7 +13,7 @@ class PubmedResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     pubmed_id = fields.Integer(required=True)
     doi = fields.String(allow_none=True)
-    url_link = fields.String()
+    publication_type = fields.String(allow_none=True)
     date_created = fields.DateTime(allow_none=True)
     date_completed = fields.DateTime(allow_none=True)
     date_revised = fields.DateTime(allow_none=True)
@@ -25,5 +27,17 @@ class PubmedResourceSchema(Schema):
     author_list = fields.String(allow_none=True)
     keyword_list = fields.String(allow_none=True)
     chemical_list = fields.String(allow_none=True)
+    mesh_list = fields.String(allow_none=True)
     coi_statement = fields.String(allow_none=True)
     updated_at = fields.DateTime()
+
+    @pre_load
+    def convert_string_to_datetime(self, in_data):
+        date_fields = ['date_created', 'date_completed', 'date_revised']
+
+        in_data = pre_load_date_fields(
+            in_data,
+            date_fields,
+            date_format='%Y%m%d',
+        )
+        return in_data
